package com.zd.exam.mapper;

import com.zd.exam.domain.ElPassMarkconfig;
import com.zd.exam.domain.vo.ElPassMarkconfigVO;

import java.util.List;

/**
 * 信用合格分设置Mapper接口
 *
 * @author zd
 * @date 2021-12-14
 */
public interface ElPassMarkconfigMapper
{
    /**
     * 查询信用合格分设置
     *
     * @param id 信用合格分设置主键
     * @return 信用合格分设置
     */
    public ElPassMarkconfig selectElPassMarkconfigById(Long id);

    /**
     * 查询信用合格分设置列表
     *
     * @param elPassMarkconfig 信用合格分设置
     * @return 信用合格分设置集合
     */
    public List<ElPassMarkconfigVO> selectElPassMarkconfigList(ElPassMarkconfig elPassMarkconfig);

    /**
     * 新增信用合格分设置
     *
     * @param elPassMarkconfig 信用合格分设置
     * @return 结果
     */
    public int insertElPassMarkconfig(ElPassMarkconfig elPassMarkconfig);

    /**
     * 修改信用合格分设置
     *
     * @param elPassMarkconfig 信用合格分设置
     * @return 结果
     */
    public int updateElPassMarkconfig(ElPassMarkconfig elPassMarkconfig);

    /**
     * 删除信用合格分设置
     *
     * @param id 信用合格分设置主键
     * @return 结果
     */
    public int deleteElPassMarkconfigById(Long id);

    /**
     * 批量删除信用合格分设置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElPassMarkconfigByIds(Long[] ids);
}
